sqlobject.tests.test_complex_sorting module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_complex_sorting module

class `sqlobject.tests.test_complex_sorting.` `ComplexNames`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `age`
  property `firstName`
  `j` = names_table
  property `lastName`
  property `phone`
  `q` = names_table
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `defaultOrder` = ['lastName', 'firstName', 'phone', 'age']
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_complex_sorting.ComplexNames`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'names_table'

`sqlobject.tests.test_complex_sorting.` `firstList`(names)

`sqlobject.tests.test_complex_sorting.` `nameList`(names)

`sqlobject.tests.test_complex_sorting.` `setupComplexNames`()

`sqlobject.tests.test_complex_sorting.` `test_complexOrders`()

`sqlobject.tests.test_complex_sorting.` `test_defaultComplexOrder`()